@@ -1,10 +1,15 @@
 require "ruby_prof.so"
 
+require "ruby-prof/method_info"
+require "ruby-prof/call_info"
+require "ruby-prof/aggregate_call_info"
 require "ruby-prof/flat_printer"
 require "ruby-prof/graph_printer"
 require "ruby-prof/graph_html_printer"
 require "ruby-prof/call_tree_printer"
 
+require "ruby-prof/test"
+
 module RubyProf
   # See if the user specified the clock mode via 
   # the RUBY_PROF_MEASURE_MODE environment variable
