@@ -2,7 +2,6 @@
 
 require 'test/unit'
 require 'ruby-prof'
-require 'test_helper'
 
 class DuplicateNames < Test::Unit::TestCase
   def test_names
@@ -22,12 +21,12 @@ class DuplicateNames < Test::Unit::TestCase
     end
     
     # There should be 3 foo methods
-    methods = result.threads.values.first
+    methods = result.threads.values.first.sort.reverse
     
     methods = methods.select do |method|
       method.full_name == 'DuplicateNames::Foo::Bar#foo'
     end
-    
+
     assert_equal(3, methods.length)
   end
 end
