@@ -1,9 +1,7 @@
 #!/usr/bin/env ruby
-
 require 'test/unit'
 require 'ruby-prof'
 require 'prime'
-require 'test_helper'
 
 class LineNumbers
   def method1
@@ -11,6 +9,7 @@ class LineNumbers
   end
   
   def method2
+    a = 3
     method1
   end
   
@@ -33,15 +32,15 @@ class LineNumbersTest < Test::Unit::TestCase
     
     method = methods[0]
     assert_equal('LineNumbersTest#test_function_line_no', method.full_name)
-    assert_equal(28, method.line)
+    assert_equal(27, method.line)
     
     method = methods[1]
-    assert_equal('LineNumbers#method1', method.full_name)
-    assert_equal(9, method.line)
+    assert_equal('LineNumbers#method2', method.full_name)
+    assert_equal(11, method.line)
     
     method = methods[2]
-    assert_equal('LineNumbers#method2', method.full_name)
-    assert_equal(13, method.line)
+    assert_equal('LineNumbers#method1', method.full_name)
+    assert_equal(7, method.line)
   end
   
   def test_c_function
@@ -51,19 +50,24 @@ class LineNumbersTest < Test::Unit::TestCase
       numbers.method3
     end
 
-    methods = result.threads.values.first.sort.reverse
+    methods = result.threads.values.first.sort_by {|method| method.full_name}
     assert_equal(3, methods.length)
-    
+
+    # Methods:
+    #   LineNumbers#method3
+    #   LineNumbersTest#test_c_function
+    #   Kernel#sleep
+
     method = methods[0]
-    assert_equal('LineNumbersTest#test_c_function', method.full_name)
-    assert_equal(51, method.line)
+    assert_equal('Kernel#sleep', method.full_name)
+    assert_equal(0, method.line)
     
     method = methods[1]
     assert_equal('LineNumbers#method3', method.full_name)
-    assert_equal(17, method.line)
+    assert_equal(16, method.line)
     
     method = methods[2]
-    assert_equal('Kernel#sleep', method.full_name)
-    assert_equal(0, method.line)
+    assert_equal('LineNumbersTest#test_c_function', method.full_name)
+    assert_equal(50, method.line)
   end
 end
\ No newline at end of file
