@@ -1,8 +1,6 @@
 #!/usr/bin/env ruby
-
 require 'test/unit'
 require 'ruby-prof'
-require 'test_helper'
 
 # Need to use wall time for this test due to the sleep calls
 RubyProf::measure_mode = RubyProf::WALL_TIME
@@ -33,20 +31,19 @@ class ModuleTest < Test::Unit::TestCase
       hello
     end
 
-    methods = result.threads.values.first
-    methods = methods.sort.reverse
+    methods = result.threads.values.first.sort.reverse
       
-    # Length should be 4
+    # Length should be 5
     assert_equal(5, methods.length)
     
     method = methods[0]
     assert_equal('ModuleTest#test_nested_modules', method.full_name)
     
     method = methods[1]
-    assert_equal('Kernel#sleep', method.full_name)
-    
-    method = methods[2]
     assert_equal('Bar#hello', method.full_name)
+
+    method = methods[2]
+    assert_equal('Kernel#sleep', method.full_name)
     
     method = methods[3]
     assert_equal('<Module::Bar>#hello', method.full_name)
