@@ -1,6 +1,6 @@
 # A silly little test program that finds prime numbers.  It
 # is intentionally badly designed to show off the use
-# or ruby-prof.
+# of ruby-prof.
 # 
 # Source from http://people.cs.uchicago.edu/~bomb154/154/maclabs/profilers-lab/
 
@@ -44,7 +44,7 @@ def find_largest(primes)
 end
 
 def run_primes
-  length = 500  
+  length = 10
   maxnum = 10000
   
   # Create random numbers
@@ -55,6 +55,4 @@ def run_primes
   
   # Find the largest primes
   largest = find_largest(primes)
-end
-
-run_primes
\ No newline at end of file
+end
\ No newline at end of file
